@@ -1,6 +1,6 @@
 #######################################################################
-# $Date: 2007-05-29T05:19:01.144060Z $
-# $Revision: 1515 $
+# $Date: 2007-05-30T02:24:03.618053Z $
+# $Revision: 1519 $
 # $Author: unobe $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -8,10 +8,9 @@ package WWW::Facebook::API::Errors;
 
 use strict;
 use warnings;
-use XML::Simple qw(xml_out);
 use Carp;
 
-use version; our $VERSION = qv('0.1.1');
+use version; our $VERSION = qv('0.1.3');
 
 use Moose;
 extends 'Moose::Object';
@@ -26,28 +25,24 @@ has 'last_call_success' => ( is => 'rw', isa => 'Bool' );
 has 'last_error' => ( is => 'rw', isa => 'Str' );
 
 sub log_debug {
-    my ($self, $params, $xml ) = @_;
-    # output the raw xml and its corresponding object, for debugging:
+    my ($self, $params, $response ) = @_;
+
     my $debug =  "uri = ".$self->base->server_uri;
     $debug    .= "\n\nparams = \n";
 
     for ( keys %{$params} ) {
         $debug .= "\t$_ " . $params->{$_} . "\n";
     }
-    $debug .= "xml = \n" . xml_out( $xml );
+    $debug .= "response =\n$response\n";
     carp $debug;
     return;
 }
 
 sub log_error {
-    my ( $self, $xml ) = @_;
+    my ( $self, $error_code, $response ) = @_;
     $self->last_call_success( 0 );
-    my $error_response = $xml->{'error_response'}->[0];
-    $self->last_error( join ': ',
-        $error_response->{'error_code'}->[0],
-        $error_response->{'error_msg'}->[0]
-    );
-    if ( $self->throw_errors ) { confess xml_out( $xml ) }
+    $self->last_error( $error_code );
+    confess $response if $self->throw_errors;
     return;
 }
 
@@ -61,7 +56,7 @@ WWW::Facebook::API::Errors - Errors class for Client
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Errors version 0.1.1
+This document describes WWW::Facebook::API::Errors version 0.1.3
 
 
 =head1 SYNOPSIS
@@ -78,6 +73,10 @@ Error methods and data used by L<WWW::Facebook::API::Base>
 
 =over
 
+=item base
+
+The L<WWW::Facebook::API::Base> object to use to access settings.
+
 =item debug
 
 A boolean set to either true or false, determining if debugging messages
@@ -98,7 +97,7 @@ A string holding the error message of the last failed call to the REST server.
 
 =item log_debug
 
-Logs debugging message by carping parameters and xml returned by REST server.
+Logs debugging message by carping parameters and response returned by REST server.
 Only called if C<debug> is true.
 
 =item log_error
