@@ -1,6 +1,6 @@
 #######################################################################
-# $Date: 2007-05-29T05:19:01.144060Z $
-# $Revision: 1515 $
+# $Date: 2007-05-30T02:22:16.124936Z $
+# $Revision: 1518 $
 # $Author: unobe $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -10,44 +10,17 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.1.1');
+use version; our $VERSION = qv('0.1.3');
 
 use Moose;
 extends 'Moose::Object';
 
 has 'base' => ( is => 'ro', isa => 'WWW::Facebook::API::Base' );
 
-sub get {
-    my $self = shift;
-    my $value = $self->base->call(
-        method => 'notifications.get',
-        params => { @_ },
-    );
-    return $self->base->simple
-        ? $value->{notifications_get_response}->[0]
-        : $value;
-}
-
-sub send {
-    my $self = shift;
-    my $value = $self->base->call(
-        method => 'notifications.send',
-        params => { @_ },
-    );
-    return $self->base->simple
-        ? $value->{notifications_send_response}->[0]
-        : $value;
-}
-
+sub get     { shift->base->call( 'notifications.get', @_ )    }
+sub send    { shift->base->call( 'notifications.send', @_ )   }
 sub send_request {
-    my $self = shift;
-    my $value = $self->base->call(
-        method => 'notifications.sendRequest',
-        params => { @_ },
-    );
-    return $self->base->simple
-        ? $value->{notifications_sendRequest_response}->[0]
-        : $value;
+    shift->base->call( 'notifications.sendRequest', @_ );
 }
 
 1; # Magic true value required at end of module
@@ -60,7 +33,7 @@ WWW::Facebook::API::Notifications - Notifications methods for Client
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Notifications version 0.1.1
+This document describes WWW::Facebook::API::Notifications version 0.1.3
 
 
 =head1 SYNOPSIS
